print("import: 'boto3'")
import boto3

print("import: 'boto3.docs'")
import boto3.docs

print("import: 'boto3.dynamodb'")
import boto3.dynamodb

print("import: 'boto3.ec2'")
import boto3.ec2

print("import: 'boto3.resources'")
import boto3.resources

print("import: 'boto3.s3'")
import boto3.s3

